#
# spec file for package libgit2-glib
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2013 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libgit2-glib
Version:        1.2.0
Release:        1.1
Summary:        GLib wrapper library around libgit2
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://wiki.gnome.org/Projects/Libgit2-glib
Source0:        %{name}-%{version}.tar.xz

BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-base
# Needed to create the vala bindings
BuildRequires:  vala
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.44.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.10.1
BuildRequires:  pkgconfig(libgit2) >= 0.25.0
BuildRequires:  pkgconfig(libssh2)

%description
libgit2-glib is a GLib wrapper library around the libgit2 git access library.

%package -n libgit2-glib-1_0-0
Summary:        GLib wrapper library around libgit2
Group:          System/Libraries

%description -n libgit2-glib-1_0-0
libgit2-glib is a GLib wrapper library around the libgit2 git access library.

%package -n typelib-1_0-Ggit-1_0
Summary:        GObject introspection for libgit2-glib
Group:          System/Libraries

%description -n typelib-1_0-Ggit-1_0
libgit2-glib is a GLib wrapper library around the libgit2 git access library.

%package devel
Summary:        Development files for libgit2-glib, a GLib wrapper library around libgit2
Group:          Development/Languages/C and C++
Requires:       libgit2-glib-1_0-0 = %{version}
Requires:       typelib-1_0-Ggit-1_0 = %{version}

%description devel
libgit2-glib is a GLib wrapper library around the libgit2 git access library.

%prep
%autosetup -p1

%build
%meson \
	-Dgtk_doc=true \
	-Dintrospection=true \
	-Dpython=false \
	-Dssh=true \
	-Dvapi=true \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n libgit2-glib-1_0-0

%check
%meson_test

%files -n libgit2-glib-1_0-0
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/libgit2-glib-1.0.so.*

%files -n typelib-1_0-Ggit-1_0
%{_libdir}/girepository-1.0/Ggit-1.0.typelib

%files devel
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%doc %{_datadir}/gtk-doc/html/libgit2-glib-1.0/
%{_includedir}/libgit2-glib-1.0/
%{_libdir}/libgit2-glib-1.0.so
%{_libdir}/pkgconfig/libgit2-glib-1.0.pc
%{_datadir}/gir-1.0/Ggit-1.0.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/ggit-1.0.*
%{_datadir}/vala/vapi/libgit2-glib-1.0.*

%changelog
* Sun Sep  3 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 1.2.0:
  + diff: fix user_data parameter type.
  + ggit_repository_create_commit_from_ids: add safe checks.
  + Allow to sign commits.
  + Add mailmap support.
  + Miscelaneous of bug fixes.
- Drop bogus python3 BuildRequires: python3-base is sufficient.
* Fri Jul 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.1.0:
  + Add macro GGIT_CHECK_VERSION.
  + ggit_diff_foreach: Prevent assertions with null callbacks.
  + Map flags related to conflicts.
  + Several meson improvements.
  + Fix documentation.
- Replace gtk-doc with pkgconfig(gi-docgen) BuildRequires following
  upstreams changes.
- Use ldconfig_scriptlets macro for post(un) handling.
* Thu Dec 23 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.0.1:
  + Fix deprecation.
- Changes from version 1.0.0:
  + Allow diff without repository.
  + Allow null options on ggit_checkout API.
  + Invalid path resolving relative path on windows.
  + Add git_repository_set_head_detached to the public API.
  + Added a wrapper function for git_remote_prune.
  + Several meson improvements.
  + Misc bug fixes.
* Thu Apr 16 2020 bjorn.lie@gmail.com
- Update to version 0.99.0+16:
  + Check subcommand execution
  + tests: Replace use of deprecated GTimeVal
  + ggit_object_factory: Replace use of deprecated g_object_newv
  + ggit_object_factory: Fix constructor return type
  + ggit_submodule_update: Fix constness of update options
  + ggit_repository_merge: Fix constness of their_heads_native
  + examples: Fix clone example's compiler warnings
  + meson_vapi_link.py: Use python's own utils instead of calling 'ln'
  + meson_vapi_link.py: Improve calculation of vapidir
  + meson_vapi_link.py: Remove unnecessary os.path.join
- Switch to git checkout via source service.
* Thu Apr 16 2020 bjorn.lie@gmail.com
- Update to version 0.99.0.1:
  + git_merge: fix their_heads_length parameter
  + Use correct free functions
  + Detect libgit2 version
- Changes from version 0.99.0:
  + Detect libgit2 version
  + Added ggit_repository_rename_remote
  + Added ggit_repository_set_remote_url
  + Added ggit_repository_remove_remote
  + Use python3
  + Added ggit_diff_new_buffers.
- Add explicit python3-base BuildRequires following upstreams
  changes.
- Add check section and pass meson_test macro, run test-suite
  during build.
* Tue May  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.28.0.1:
  + Added push support.
  + Add merge support.
  + Fix macOS support.
  + Add push operation.
  + Compatibility with libgit2 0.28.
  + Several meson improvements.
  + Misc bug fixes.
- Drop libgit2-glib-libgit2_028-compat.patch: Fixed upstream.
* Wed Feb 13 2019 bjorn.lie@gmail.com
- Add libgit2-glib-libgit2_028-compat.patch: Fix build with libgit2
  0.28 version. Patch from upstream merge requests.
* Wed Feb 13 2019 bjorn.lie@gmail.com
- Update to version 0.27.8:
  + Add body property to DiffFormatEmailOptions.
  + Add submodule update.
  + Fix missing struct field init in branch enumerator.
  + Fix cross compilation builds.
  + Several meson improvements.
* Wed Nov 14 2018 kdalamagkidis@suse.com
- Update to version 0.27.7:
  + pkg-config pc file generation fixed
  + Fix cached hunks
- Remove libgit2-glib-libgit2-0.27.0.patch: Version 0.27.7 added
  support for libgit2 0.27.0
* Wed Apr 25 2018 dimstar@opensuse.org
- Add libgit2-glib-libgit2-0.27.0.patch: Fix build with libgit2
  0.27.0. Patch only conditionally applied.
* Sat Mar  3 2018 bjorn.lie@gmail.com
- Update to version 0.26.4:
  + Make meson the official build system.
  + Misc bug fixes.
- Switch to meson buildsystem following upstreams port, add meson
  BuildRequires and use meson macros as well as pass explicit
  options to meson, build the features we want.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Dec 13 2017 jengelh@inai.de
- Fix spelling project names again. Adjust RPM group.
* Thu Nov 30 2017 luc14n0@linuxmail.org
- Update to version 0.26.2:
  + Several fixes on the annotations.
  + Misc bug fixes.
- Update Url to https://wiki.gnome.org/Projects/Libgit2-glib:
  current Libgit2-glib project's web page.
- Adopt the use of %%make_build macro instead of raw make command,
  following the best practices.
- Add missing gtk-doc BuildRequires and pass enable-gtk-doc to
  configure once the API documentation is desired.
- Correct the library's name spelling in summaries and
  descriptions.
* Sat Aug  5 2017 zaitor@opensuse.org
- Update to version 0.26.0:
  + Port to libgit2 0.26.x.
* Mon Feb 20 2017 astieger@suse.com
- Update to version 0.25.0:
  + Port to libgit2 0.25.x.
  + Add initial version of meson build system.
* Wed Sep  7 2016 zaitor@opensuse.org
- Update to version 0.24.4:
  + Do not stat index entry when restoring from blob (bgo#770956).
* Fri Aug 26 2016 dimstar@opensuse.org
- Update to version 0.24.3:
  + Reduce memory allocations during diff generation.
  + Fix ctime in index entry.
* Wed Aug 17 2016 zaitor@opensuse.org
- Update to version 0.24.2:
  + Fix several crashes.
  + Misc bugfixing.
* Mon May  9 2016 sreeves@suse.com
- Add to the SDK. Fate#319349
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 0.24.0:
  + Fix api breaks made in libgit2.
  + Misc bugfixing.
* Sat Feb  6 2016 zaitor@opensuse.org
- Update to version 0.23.10:
  + Protected against empty signature.
  + Do not mandatorily require gtkdocize.
* Sun Dec 13 2015 zaitor@opensuse.org
- Update to version 0.23.8:
  + Misc bugfixing.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 0.23.6:
  + Fix corrupted memory on diff.
  + Bind more api.
  + Misc bugfixing.
* Fri Aug  7 2015 zaitor@opensuse.org
- Update to version 0.23.4:
  + Bind more api.
  + Misc bugfixing.
* Tue Aug  4 2015 zaitor@opensuse.org
- Update to version 0.23.2:
  + Add ggit_config_snapshot.
  + Allow to enable debug builds.
  + Misc bugfixing.
* Tue Jul 28 2015 dimstar@opensuse.org
- Update to version 0.23.0:
  + Fix api breaks made in libgit2.
  + Misc bugfixing.
- Add pkgconfig(libssh2) BuildRequires: New dependency.
* Fri May 15 2015 dimstar@opensuse.org
- Update to version 0.22.8:
  + Include passed in cflags for ssh check.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 0.22.6:
  + Add ggit_repository_path_is_ignored.
* Tue Apr  7 2015 zaitor@opensuse.org
- Update to version 0.22.4:
  + Fix crash when cloning.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 0.22.2:
  + Misc bugfixes.
* Tue Jan 27 2015 dimstar@opensuse.org
- Update to version 0.22.0:
  + Fix api breaks made in libgit2.
  + Follow libgit2's version.
  + Misc bugfixing.
* Mon Dec 29 2014 zaitor@opensuse.org
- Update to version 0.0.24:
  + Support Notes.
  + Misc bugfixing.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 0.0.22:
  + More API support.
  + Fixes to build on win32.
* Thu Jul 24 2014 dimstar@opensuse.org
- Update to version 0.0.20:
  + More API support.
  + Added vala bindings.
  + Fixes to build on win32.
* Thu Jul 10 2014 dimstar@opensuse.org
- Update to version 0.0.18:
  + Add checkout API.
  + Add ssh credential schemes.
  + Improve coverage.
  + Cover more of the API.
- Changes from version 0.0.16:
  + Fix important crash.
- Changes from version 0.0.14:
  + Bump libgit2 requirement to 0.21.0.
  + API changes to match libgit2 0.21.0 API.
  + Misc bugfixing.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 0.0.12:
  + Add push progress API.
  + Fix install of pygobject overrides.
  + Bump libgit2 requirement to 0.20.0.
  + Misc bugfixing.
* Sat Jan  4 2014 dimstar@opensuse.org
- Update to version 0.0.10:
  + Bind blaming API.
  + Initial binding of attribute API.
  + Automatic conversion of diff text to UTF-8.
  + Fixes in GgitBlobOutputStream.
* Mon Nov 25 2013 dimstar@opensuse.org
- Update to version 0.0.8:
  + Add ggit_patch_get_hunk.
  + Added ggit_patch_get_delta.
  + Add API to set remote callbacks in clone options.
  + Add _ggit_native_release.
  + Implement GgitRemoteCallbacks.
  + Added coverage tool.
  + Update enums.
  + Rename _head_orphan to _head_unborn.
  + Implemented branch enumerator.
  + Added GgitRemoteHead.
  + Add GgitDiffHunk.
  + Add GgitDiffLine.
  + Update to libgit2 0.20.0 api.
  + Misc bugfixing.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 0.0.6:
  + Rename GgitDiff to GgitDiffList.
  + Bind GgitMergeTreeOptions.
  + Added ggit_diff_patch_to_stream.
  + Added writing blob using output stream.
  + Bind more index API (write_tree, add_bypath, owner).
  + Rename FILEMODE constants to FILE_MODE.
  + Bind create_commit.
  + Bind ggit_message_prettify.
  + Bind get_patch and patch_to_string.
  + Added new status options.
  + Added ggit_index_entry_stat.
  + Added _set API for GgitIndexEntry.
  + Bind tree builder API.
  + Misc bugfixing.
* Thu Jun 27 2013 dimstar@opensuse.org
- Update to version 0.0.4:
  + Update bindings to the latest libgit2 API changes 0.19.0.
  + Rename GgitStatusFlag to GgitStatusOption.
  + Add GgitStatusOptions.
  + Added tree builder API.
  + Bind create_blob_from... API.
  + Misc bugfixing.
* Fri Jun 21 2013 dimstar@opensuse.org
- Initial package, version 0.0.2.
